@@ -1,17 +1,43 @@
+#------------------------------------------------------------------------------#
+#
+#                /$$
+#               | $$
+#     /$$$$$$  /$$$$$$
+#    /$$__  $$|_  $$_/
+#   | $$  \ $$  | $$
+#   | $$  | $$  | $$ /$$
+#   |  $$$$$$$  |  $$$$/
+#    \____  $$   \___/
+#    /$$  \ $$
+#   |  $$$$$$/
+#    \______/
+#
+#  This file is part of the 'rstudio/gt' project.
+#
+#  Copyright (c) 2018-2023 gt authors
+#
+#  For full copyright and license information, please look at
+#  https://gt.rstudio.com/LICENSE.html
+#
+#------------------------------------------------------------------------------#
+
+
 #' @noRd
 compile_scss <- function(data, id = NULL) {
 
   # Obtain the SCSS options table from `data`
   gt_options_tbl <- dt_options_get(data = data)
 
-  gt_options_tbl <- gt_options_tbl[gt_options_tbl$scss & !is.na(gt_options_tbl$value), ]
+  gt_options_tbl <-
+    gt_options_tbl[gt_options_tbl$scss & !is.na(gt_options_tbl$value), ]
 
   color_rows <- grepl("_color", gt_options_tbl$parameter)
 
   gt_options_tbl <-
     within(
       gt_options_tbl,{
-        value[color_rows] = value[color_rows] <- lapply(value[color_rows], html_color)
+        value[color_rows] = value[color_rows] <-
+          lapply(value[color_rows], html_color)
       }
     )
 
