@@ -1,3 +1,27 @@
+#------------------------------------------------------------------------------#
+#
+#                /$$
+#               | $$
+#     /$$$$$$  /$$$$$$
+#    /$$__  $$|_  $$_/
+#   | $$  \ $$  | $$
+#   | $$  | $$  | $$ /$$
+#   |  $$$$$$$  |  $$$$/
+#    \____  $$   \___/
+#    /$$  \ $$
+#   |  $$$$$$/
+#    \______/
+#
+#  This file is part of the 'rstudio/gt' project.
+#
+#  Copyright (c) 2018-2023 gt authors
+#
+#  For full copyright and license information, please look at
+#  https://gt.rstudio.com/LICENSE.html
+#
+#------------------------------------------------------------------------------#
+
+
 .dt_boxhead_key <- "_boxhead"
 
 dt_boxhead_get <- function(data) {
@@ -31,22 +55,21 @@ dt_boxhead_init <- function(data) {
       # - `default` appears as a column with values below
       # - `stub` appears as part of a table stub, set to the left
       #   and styled differently
-      # - `row_group` uses values as categoricals and groups rows
+      # - `row_group` uses categorical values and groups rows
       #   under row group headings
       # - `hidden` hides this column from the final table render
       #   but retains values to use in expressions
       # - `hidden_at_px` similar to hidden but takes a list of
       #   screen widths (in px) whereby the column would be hidden
       type = "default",
-      # # The shared spanner label between columns, where column names
-      # # act as the keys
-      # spanner_label = empty_list,
-      # # The label for row groups, which is maintained as a list of
-      # # labels by render context (e.g., HTML, LaTeX, etc.)
-      # row_group_label = lapply(seq_along(names(data)), function(x) NULL),
       # The presentation label, which is a list of labels by
       # render context (e.g., HTML, LaTeX, etc.)
       column_label = as.list(column_labels),
+      # Units for the column label, written in a shorthand notation
+      column_units = NA_character_,
+      # A pattern to use when arranging the `column_label` and the
+      # `column_units`
+      column_pattern = NA_character_,
       # The alignment of the column ("left", "right", "center")
       column_align = "center",
       # The width of the column in `px`
@@ -68,7 +91,7 @@ dt_boxhead_edit <- function(data, var, ...) {
   val_list <- list(...)
 
   if (length(val_list) != 1) {
-    cli::cli_abort("`dt_boxhead_edit()` expects a single value at `...`.")
+    cli::cli_abort("{.fn dt_boxhead_edit} expects a single value at `{cli::symbol$ellipsis}`.")
   }
 
   check_names_dt_boxhead_expr(expr = val_list)
@@ -89,6 +112,8 @@ dt_boxhead_add_var <- function(
     var,
     type,
     column_label = list(var),
+    column_units = NA_character_,
+    column_pattern = NA_character_,
     column_align = "left",
     column_width = list(NULL),
     hidden_px = list(NULL),
@@ -102,17 +127,18 @@ dt_boxhead_add_var <- function(
       var = var,
       type = type,
       column_label = column_label,
+      column_units = column_units,
+      column_pattern = column_pattern,
       column_align = column_align,
       column_width = column_width,
       hidden_px = hidden_px
     )
+  add_where <- rlang::arg_match0(add_where, c("top", "bottom"))
 
   if (add_where == "top") {
     dt_boxhead <- dplyr::bind_rows(dt_boxhead_row, dt_boxhead)
   } else if (add_where == "bottom") {
     dt_boxhead <- dplyr::bind_rows(dt_boxhead, dt_boxhead_row)
-  } else {
-    cli::cli_abort("The `add_where` value must be either `top` or `bottom`.")
   }
 
   dt_boxhead_set(data = data, boxh = dt_boxhead)
@@ -165,6 +191,24 @@ dt_boxhead_edit_column_label <- function(data, var, column_label) {
   )
 }
 
+dt_boxhead_edit_column_units <- function(data, var, column_units) {
+
+  dt_boxhead_edit(
+    data = data,
+    var = var,
+    column_units = column_units
+  )
+}
+
+dt_boxhead_edit_column_pattern <- function(data, var, column_pattern) {
+
+  dt_boxhead_edit(
+    data = data,
+    var = var,
+    column_pattern = column_pattern
+  )
+}
+
 dt_boxhead_get_vars <- function(data) {
   dt_boxhead_get(data = data)$var
 }
@@ -239,7 +283,8 @@ dt_boxhead_get_alignment_by_var <- function(data, var) {
 check_names_dt_boxhead_expr <- function(expr) {
 
   if (!all(names(expr) %in% c(
-    "type", "column_label", "column_align", "column_width", "hidden_px"
+    "type", "column_label", "column_units", "column_pattern",
+    "column_align", "column_width", "hidden_px"
   ))) {
     cli::cli_abort("Expressions must use names available in `dt_boxhead`.")
   }
@@ -259,6 +304,54 @@ dt_boxhead_build <- function(data, context) {
   boxh$column_label <-
     lapply(boxh$column_label, function(label) process_text(label, context))
 
+  # Merge column units into column labels
+  if (!all(is.na(boxh$column_units))) {
+
+    for (i in seq_along(boxh$column_label)) {
+
+      if (is.na(boxh[["column_units"]][i])) next
+
+      column_label <- unlist(boxh[["column_label"]][i])
+
+      units <- boxh[["column_units"]][i]
+      column_pattern <- boxh[["column_pattern"]][i]
+
+      units_built <-
+        render_units(
+          define_units(units_notation = units),
+          context = context
+        )
+
+      if (column_pattern == "" && grepl(units, column_label, fixed = TRUE)) {
+
+        # With `column_pattern` equal to `""`, we can surmise that this was
+        # set automatically by `cols_label()`; the mechanism now is to replace
+        # the units text in the label with the 'built' units text
+
+        column_label <- gsub(units, units_built, column_label, fixed = TRUE)
+
+      } else {
+
+        if (is.na(column_pattern)) {
+
+          # Obtain the default `column_pattern` (which that is settable in the
+          # `column_labels.units_pattern` option of `tab_options()`
+          column_pattern <-
+            dt_options_get_value(
+              data = data,
+              option = "column_labels_units_pattern"
+            )
+        }
+
+        column_pattern <- gsub("{1}", column_label, column_pattern, fixed = TRUE)
+        column_pattern <- gsub("{2}", units_built, column_pattern, fixed = TRUE)
+        column_label <- column_pattern
+      }
+
+      boxh$column_label[i] <- list(column_label)
+    }
+  }
+
   dt_boxhead_set(data = data, boxh = boxh)
 }
 
